import React, { useState, useEffect, useCallback, useRef } from 'react';
import { MagnifyingGlassIcon, XMarkIcon } from '@heroicons/react/24/solid';
import { useNavigate } from 'react-router-dom';
import { openCandApi, type Candidate, ApiError } from '../api';
import { mockSearchCandidates, DEMO_CONFIG } from '../config/demo';

const HeroSection: React.FC = () => {
  const [searchQuery, setSearchQuery] = useState('');
  const [searchResults, setSearchResults] = useState<Candidate[]>([]);
  const [isLoading, setIsLoading] = useState(false);
  const [showResults, setShowResults] = useState(false);
  const [error, setError] = useState<string | null>(null);
  const navigate = useNavigate();
  const searchTimeoutRef = useRef<number | null>(null);
  const resultsRef = useRef<HTMLDivElement>(null);

  // Debounced search function
  const performSearch = useCallback(async (query: string) => {
    if (query.trim().length < 2) {
      setSearchResults([]);
      setShowResults(false);
      setError(null);
      return;
    }

    setIsLoading(true);
    setError(null);

    try {
      let result;
      
      // Use mock data if configured or if API call fails
      if (DEMO_CONFIG.useMockData) {
        result = await mockSearchCandidates(query.trim());
      } else {
        try {
          result = await openCandApi.searchCandidates(query.trim());
        } catch (apiError) {
          console.warn('API call failed, falling back to mock data:', apiError);
          result = await mockSearchCandidates(query.trim());
        }
      }
      
      setSearchResults(result.candidatos.slice(0, 8)); // Limit to 8 results
      setShowResults(true);
    } catch (err) {
      if (err instanceof ApiError) {
        setError(`Erro na busca: ${err.message}`);
      } else {
        setError('Erro inesperado na busca');
      }
      setSearchResults([]);
      setShowResults(false);
    } finally {
      setIsLoading(false);
    }
  }, []);

  // Handle input change with debouncing
  const handleInputChange = useCallback((e: React.ChangeEvent<HTMLInputElement>) => {
    const query = e.target.value;
    setSearchQuery(query);

    // Clear previous timeout
    if (searchTimeoutRef.current) {
      clearTimeout(searchTimeoutRef.current);
    }

    // Set new timeout for debounced search
    searchTimeoutRef.current = window.setTimeout(() => {
      performSearch(query);
    }, 300); // 300ms delay
  }, [performSearch]);

  // Handle candidate selection
  const handleCandidateSelect = useCallback((candidate: Candidate) => {
    navigate(`/candidato/${candidate.idCandidato}`);
    setShowResults(false);
    setSearchQuery('');
  }, [navigate]);

  // Handle form submission
  const handleSubmit = useCallback((e: React.FormEvent) => {
    e.preventDefault();
    if (searchResults.length > 0) {
      handleCandidateSelect(searchResults[0]);
    }
  }, [searchResults, handleCandidateSelect]);

  // Close results when clicking outside
  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      if (resultsRef.current && !resultsRef.current.contains(event.target as Node)) {
        setShowResults(false);
      }
    };

    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, []);

  // Clear timeout on unmount
  useEffect(() => {
    return () => {
      if (searchTimeoutRef.current) {
        clearTimeout(searchTimeoutRef.current);
      }
    };
  }, []);

  return (
    <section 
      className="min-h-screen flex flex-col justify-center items-center text-white p-4 bg-cover bg-center bg-no-repeat bg-gray-900 relative"
      style={{ backgroundImage: "url('https://upload.wikimedia.org/wikipedia/commons/thumb/2/21/National_Congress_of_Brazil%2C_Brasilia.jpg/1024px-National_Congress_of_Brazil%2C_Brasilia.jpg')" }}
    >
      <div className="absolute inset-0 bg-black/60"></div>
      <div className="relative z-10 text-center max-w-3xl">
        <h1 className="text-5xl md:text-7xl font-bold mb-6">
          Explore Dados Eleitorais
        </h1>
        <p className="text-lg md:text-xl mb-10 text-gray-300">
          OpenCand oferece acesso fácil e visualizações intuitivas de dados abertos do Tribunal Superior Eleitoral (TSE) do Brasil.
        </p>
        
        <div className="w-full max-w-xl mx-auto relative" ref={resultsRef}>
          <form onSubmit={handleSubmit}>
            <div className="flex items-center bg-white/10 backdrop-blur-sm rounded-full shadow-xl p-2 transition-all duration-200 hover:bg-white/15">
              <MagnifyingGlassIcon className="h-6 w-6 text-gray-400 ml-3" />
              <input
                value={searchQuery}
                onChange={handleInputChange}
                placeholder="Pesquisar candidatos..." 
                className="flex-grow bg-transparent text-white placeholder-gray-400 p-3 focus:outline-none"
                autoComplete="off"
              />
              {isLoading && (
                <div className="mr-3">
                  <div className="animate-spin rounded-full h-5 w-5 border-2 border-white border-t-transparent"></div>
                </div>
              )}
              {searchQuery && !isLoading && (
                <button
                  type="button"
                  onClick={() => {
                    setSearchQuery('');
                    setSearchResults([]);
                    setShowResults(false);
                    setError(null);
                  }}
                  className="mr-3 p-1 hover:bg-white/20 rounded-full transition-colors"
                >
                  <XMarkIcon className="h-4 w-4 text-gray-400" />
                </button>
              )}
            </div>
          </form>

          {/* Search Results Dropdown */}
          {showResults && (searchResults.length > 0 || error) && (
            <div className="absolute top-full left-0 right-0 mt-2 bg-white rounded-xl shadow-2xl border border-gray-200 overflow-hidden z-50">
              {error ? (
                <div className="p-4 text-red-600 text-center bg-white">
                  {error}
                </div>
              ) : (
                <div className="max-h-80 overflow-y-auto custom-scrollbar">
                  {searchResults.map((candidate) => (
                    <button
                      key={candidate.idCandidato}
                      onClick={() => handleCandidateSelect(candidate)}
                      className="w-full p-4 text-left hover:bg-gray-100 transition-colors border-b border-gray-100 last:border-b-0 focus:outline-none focus:bg-gray-100"
                    >
                      <div className="text-black font-semibold text-base">{candidate.nome}</div>
                      <div className="text-gray-600 text-sm mt-1">
                        CPF: {candidate.cpf} | {candidate.ocupacao}
                      </div>
                      {candidate.email && (
                        <div className="text-gray-500 text-xs mt-1">{candidate.email}</div>
                      )}
                    </button>
                  ))}
                  
                  {searchResults.length === 8 && (
                    <div className="p-3 text-center text-gray-500 text-sm bg-gray-50">
                      Mostrando os primeiros 8 resultados
                    </div>
                  )}
                </div>
              )}
            </div>
          )}

          {/* No results message */}
          {showResults && searchResults.length === 0 && !error && !isLoading && searchQuery.length >= 2 && (
            <div className="absolute top-full left-0 right-0 mt-2 bg-white rounded-xl shadow-2xl border border-gray-200 overflow-hidden z-50">
              <div className="p-4 text-gray-600 text-center">
                Nenhum candidato encontrado para "{searchQuery}"
              </div>
            </div>
          )}
        </div>
      </div>
    </section>
  );
};

export default HeroSection;
